==> qtjambi-qt3drender-6.2.9-sources.jar: io/qt/qt3d/render/QStencilMask.java <==
package io.qt.qt3d.render;


/**
 * <p>Controls the front and back writing of individual bits in the stencil planes</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qt3drender-qstencilmask.html">Qt3DRender::QStencilMask</a></p>
 */
public class QStencilMask extends io.qt.qt3d.render.QRenderState
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QStencilMask.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qstencilmask.html#backOutputMask-prop">Qt3DRender::QStencilMask::backOutputMaskChanged(uint)</a></p>
     */
    @io.qt.QtPropertyNotify(name="backOutputMask")
    public final Signal1<@io.qt.QtPrimitiveType Integer> backOutputMaskChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qstencilmask.html#frontOutputMask-prop">Qt3DRender::QStencilMask::frontOutputMaskChanged(uint)</a></p>
     */
    @io.qt.QtPropertyNotify(name="frontOutputMask")
    public final Signal1<@io.qt.QtPrimitiveType Integer> frontOutputMaskChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QStencilMask(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QStencilMask() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qstencilmask.html#QStencilMask">Qt3DRender::QStencilMask::QStencilMask(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QStencilMask(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QStencilMask instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qstencilmask.html#backOutputMask-prop">Qt3DRender::QStencilMask::backOutputMask()const</a></p>
     */
    @io.qt.QtPropertyReader(name="backOutputMask")
    @io.qt.QtUninvokable
    public final int backOutputMask(){
        return backOutputMask_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int backOutputMask_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qstencilmask.html#frontOutputMask-prop">Qt3DRender::QStencilMask::frontOutputMask()const</a></p>
     */
    @io.qt.QtPropertyReader(name="frontOutputMask")
    @io.qt.QtUninvokable
    public final int frontOutputMask(){
        return frontOutputMask_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int frontOutputMask_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qstencilmask.html#backOutputMask-prop">Qt3DRender::QStencilMask::setBackOutputMask(uint)</a></p>
     */
    @io.qt.QtPropertyWriter(name="backOutputMask")
    public final void setBackOutputMask(int backOutputMask){
        setBackOutputMask_native_uint(QtJambi_LibraryUtilities.internal.nativeId(this), backOutputMask);
    }
    
    private native void setBackOutputMask_native_uint(long __this__nativeId, int backOutputMask);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qstencilmask.html#frontOutputMask-prop">Qt3DRender::QStencilMask::setFrontOutputMask(uint)</a></p>
     */
    @io.qt.QtPropertyWriter(name="frontOutputMask")
    public final void setFrontOutputMask(int frontOutputMask){
        setFrontOutputMask_native_uint(QtJambi_LibraryUtilities.internal.nativeId(this), frontOutputMask);
    }
    
    private native void setFrontOutputMask_native_uint(long __this__nativeId, int frontOutputMask);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QStencilMask(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QStencilMask(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QStencilMask instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-6.5.0-sources.jar: io/qt/qt3d/render/QStencilMask.java <==
package io.qt.qt3d.render;

import io.qt.*;


/**
 * <p>Controls the front and back writing of individual bits in the stencil planes</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qt3drender-qstencilmask.html">Qt3DRender::QStencilMask</a></p>
 */
public class QStencilMask extends io.qt.qt3d.render.QRenderState
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QStencilMask.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qstencilmask.html#backOutputMask-prop">Qt3DRender::QStencilMask::backOutputMaskChanged(uint)</a></p>
     */
    @QtPropertyNotify(name="backOutputMask")
    public final @NonNull Signal1<java.lang.@QtPrimitiveType@NonNull Integer> backOutputMaskChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qstencilmask.html#frontOutputMask-prop">Qt3DRender::QStencilMask::frontOutputMaskChanged(uint)</a></p>
     */
    @QtPropertyNotify(name="frontOutputMask")
    public final @NonNull Signal1<java.lang.@QtPrimitiveType@NonNull Integer> frontOutputMaskChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QStencilMask(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QStencilMask() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qstencilmask.html#QStencilMask">Qt3DRender::QStencilMask::QStencilMask(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QStencilMask(io.qt.qt3d.core.@Nullable QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QStencilMask instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>Kotlin property getter. In Java use {@link #backOutputMask()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final int getBackOutputMask() {
        return backOutputMask();
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qstencilmask.html#backOutputMask-prop">Qt3DRender::QStencilMask::backOutputMask()const</a></p>
     */
    @QtPropertyReader(name="backOutputMask")
    @QtUninvokable
    public final int backOutputMask(){
        return backOutputMask_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int backOutputMask_native_constfct(long __this__nativeId);
    
    /**
     * <p>Kotlin property getter. In Java use {@link #frontOutputMask()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final int getFrontOutputMask() {
        return frontOutputMask();
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qstencilmask.html#frontOutputMask-prop">Qt3DRender::QStencilMask::frontOutputMask()const</a></p>
     */
    @QtPropertyReader(name="frontOutputMask")
    @QtUninvokable
    public final int frontOutputMask(){
        return frontOutputMask_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int frontOutputMask_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qstencilmask.html#backOutputMask-prop">Qt3DRender::QStencilMask::setBackOutputMask(uint)</a></p>
     */
    @QtPropertyWriter(name="backOutputMask")
    public final void setBackOutputMask(int backOutputMask){
        setBackOutputMask_native_uint(QtJambi_LibraryUtilities.internal.nativeId(this), backOutputMask);
    }
    
    private native void setBackOutputMask_native_uint(long __this__nativeId, int backOutputMask);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qstencilmask.html#frontOutputMask-prop">Qt3DRender::QStencilMask::setFrontOutputMask(uint)</a></p>
     */
    @QtPropertyWriter(name="frontOutputMask")
    public final void setFrontOutputMask(int frontOutputMask){
        setFrontOutputMask_native_uint(QtJambi_LibraryUtilities.internal.nativeId(this), frontOutputMask);
    }
    
    private native void setFrontOutputMask_native_uint(long __this__nativeId, int frontOutputMask);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QStencilMask(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QStencilMask(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QStencilMask instance, QDeclarativeConstructor constructor);
    
}
